@@ -17,13 +17,20 @@
 # 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
 
 
-from datetime import datetime
 import os
-from shlex import split as shlsplit
+import shlex
 import signal
-from subprocess import Popen, PIPE
 from select import select
 import socket
+import time
+
+# Try-and-ignore import so platforms w/o subprocess (eg Google App Engine) can
+# still import paramiko.
+subprocess, subprocess_import_error = None, None
+try:
+    import subprocess
+except ImportError as e:
+    subprocess_import_error = e
 
 from paramiko.ssh_exception import ProxyCommandFailure
 from paramiko.util import ClosingContextManager
@@ -37,9 +44,10 @@ class ProxyCommand(ClosingContextManager):
     `.Transport` and `.Packetizer` classes. Using this class instead of a
     regular socket makes it possible to talk with a Popen'd command that will
     proxy traffic between the client and a server hosted in another machine.
-    
+
     Instances of this class may be used as context managers.
     """
+
     def __init__(self, command_line):
         """
         Create a new CommandProxy instance. The instance created by this
@@ -48,10 +56,17 @@ class ProxyCommand(ClosingContextManager):
         :param str command_line:
             the command that should be executed and used as the proxy.
         """
-        self.cmd = shlsplit(command_line)
-        self.process = Popen(self.cmd, stdin=PIPE, stdout=PIPE, stderr=PIPE)
+        if subprocess is None:
+            raise subprocess_import_error
+        self.cmd = shlex.split(command_line)
+        self.process = subprocess.Popen(
+            self.cmd,
+            stdin=subprocess.PIPE,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE,
+            bufsize=0,
+        )
         self.timeout = None
-        self.buffer = []
 
     def send(self, content):
         """
@@ -67,7 +82,7 @@ class ProxyCommand(ClosingContextManager):
             # died and we can't proceed. The best option here is to
             # raise an exception informing the user that the informed
             # ProxyCommand is not working.
-            raise ProxyCommandFailure(' '.join(self.cmd), e.strerror)
+            raise ProxyCommandFailure(" ".join(self.cmd), e.strerror)
         return len(content)
 
     def recv(self, size):
@@ -76,33 +91,44 @@ class ProxyCommand(ClosingContextManager):
 
         :param int size: how many chars should be read
 
-        :return: the length of the read content, as an `int`
+        :return: the string of bytes read, which may be shorter than requested
         """
         try:
-            start = datetime.now()
-            while len(self.buffer) < size:
+            buffer = b""
+            start = time.time()
+            while len(buffer) < size:
+                select_timeout = None
                 if self.timeout is not None:
-                    elapsed = (datetime.now() - start).microseconds
-                    timeout = self.timeout * 1000 * 1000  # to microseconds
-                    if elapsed >= timeout:
+                    elapsed = time.time() - start
+                    if elapsed >= self.timeout:
                         raise socket.timeout()
-                r, w, x = select([self.process.stdout], [], [], 0.0)
+                    select_timeout = self.timeout - elapsed
+
+                r, w, x = select([self.process.stdout], [], [], select_timeout)
                 if r and r[0] == self.process.stdout:
-                    b = os.read(self.process.stdout.fileno(), 1)
-                    # Store in class-level buffer for persistence across
-                    # timeouts; this makes us act more like a real socket
-                    # (where timeouts don't actually drop data.)
-                    self.buffer.append(b)
-            result = ''.join(self.buffer)
-            self.buffer = []
-            return result
+                    buffer += os.read(
+                        self.process.stdout.fileno(), size - len(buffer)
+                    )
+            return buffer
         except socket.timeout:
+            if buffer:
+                # Don't raise socket.timeout, return partial result instead
+                return buffer
             raise  # socket.timeout is a subclass of IOError
         except IOError as e:
-            raise ProxyCommandFailure(' '.join(self.cmd), e.strerror)
+            raise ProxyCommandFailure(" ".join(self.cmd), e.strerror)
 
     def close(self):
         os.kill(self.process.pid, signal.SIGTERM)
 
+    @property
+    def closed(self):
+        return self.process.returncode is not None
+
+    @property
+    def _closed(self):
+        # Concession to Python 3 socket-like API
+        return self.closed
+
     def settimeout(self, timeout):
         self.timeout = timeout
